==> 0.0.6-prerelease.tar.gz: lib/src/core/widgets/progress/ModernFormProgressDialog.dart <==
part of modern_form_core;

class _ModernFormProgressDialog extends StatelessWidget {
  const _ModernFormProgressDialog({
    Key key,
    this.child,
    this.insetAnimationDuration = const Duration(milliseconds: 100),
    this.insetAnimationCurve = Curves.decelerate,
  }) : super(key: key);

  /// The widget below this widget in the tree.
  ///
  /// {@macro flutter.widgets.child}
  final Widget child;

  /// The duration of the animation to show when the system keyboard intrudes
  /// into the space that the dialog is placed in.
  ///
  /// Defaults to 100 milliseconds.
  final Duration insetAnimationDuration;

  /// The curve to use for the animation shown when the system keyboard intrudes
  /// into the space that the dialog is placed in.
  ///
  /// Defaults to [Curves.fastOutSlowIn].
  final Curve insetAnimationCurve;

  /// {@template flutter.material.dialog.shape}
  /// The shape of this dialog's border.
  ///
  /// Defines the dialog's [Material.shape].
  ///
  /// The default shape is a [RoundedRectangleBorder] with a radius of 2.0.
  /// {@endtemplate}

  @override
  Widget build(BuildContext context) {
    return AnimatedPadding(
      padding: MediaQuery.of(context).viewInsets +
          const EdgeInsets.symmetric(horizontal: 40.0, vertical: 24.0),
      duration: insetAnimationDuration,
      curve: insetAnimationCurve,
      child: MediaQuery.removeViewInsets(
        removeLeft: true,
        removeTop: true,
        removeRight: true,
        removeBottom: true,
        context: context,
        child: Center(
          child: ConstrainedBox(
            constraints: const BoxConstraints(),
            child: child,
          ),
        ),
      ),
    );
  }
}

//the code below is writeen by Vikas-Jilla and the above code is from existing material dialog library
class ModernFormProgressDialog {
  bool isDismissed = true;
  var lock = Lock();
  Timer _timer;
  BuildContext context = ModernFormGlobalContext.context;
  Future<void> dismissProgressDialog() async {
    _timer?.cancel();
    await lock.synchronized(() async {
      if (isDismissed == null || isDismissed) {
        return;
      }
      isDismissed = true;
      Navigator.of(context).pop();
    });
  }

  void showProgressDialog({
    Color barrierColor = const Color(0x55222222),
    String textToBeDisplayed,
    Duration dismissAfter = const Duration(minutes: 180),
    Function onDismiss,
    Stream<double> streamValue,
    Stream<String> streamText,
    Color progressColor,
  }) {
    dismissProgressDialog().then((_) {
      isDismissed = false;
      showGeneralDialog(
        context: context,
        barrierColor: barrierColor,
        pageBuilder: (context, animation1, animation2) {
          return _ModernFormProgressDialog(
            child: Container(
                padding: const EdgeInsets.all(20),
                child:
                    Column(mainAxisSize: MainAxisSize.min, children: <Widget>[
                  streamValue != null
                      ? StreamBuilder<double>(
                          stream: streamValue,
                          initialData: 0,
                          builder: (context, snapshot) {
                            return ModernFormProgressIndicator(
                              value: snapshot?.data ?? 0,
                              color: progressColor,
                            );
                          })
                      : ModernFormProgressIndicator(color: progressColor),
                  streamText != null
                      ? Padding(
                          padding: EdgeInsets.only(top: 20),
                          child: StreamBuilder<Object>(
                              stream: streamText,
                              initialData: "",
                              builder: (context, snapshot) {
                                return Material(
                                  color: Colors.transparent,
                                  child: Text(
                                    snapshot?.data ?? "",
                                    style: TextStyle(
                                      color: Colors.white,
                                      fontSize: ScreenUtil().setSp(14),
                                    ),
                                    textAlign: TextAlign.center,
                                  ),
                                );
                              }))
                      : textToBeDisplayed == null
                          ? Padding(
                              padding: EdgeInsets.all(0),
                            )
                          : Padding(
                              padding: EdgeInsets.only(top: 20),
                              child: Material(
                                color: Colors.transparent,
                                child: Text(
                                  textToBeDisplayed,
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: ScreenUtil().setSp(14),
                                  ),
                                  textAlign: TextAlign.center,
                                ),
                              ))
                ])),
          );
        },
        barrierDismissible: false,
        transitionDuration: const Duration(milliseconds: 100),
      ).then((dismissed) {
        isDismissed = dismissed;
      });
      if (dismissAfter == null) return;
      _timer = Timer(dismissAfter, () {
        dismissProgressDialog();
        if (onDismiss != null) onDismiss();
      });
    });
  }
}

==> 0.1.34-prerelease.tar.gz: lib/src/core/widgets/progress/ModernFormProgressDialog.dart <==
part of modern_form_core;

class _ModernFormProgressDialog extends StatelessWidget {
  const _ModernFormProgressDialog({
    Key key,
    this.child,
    this.insetAnimationDuration = const Duration(milliseconds: 100),
    this.insetAnimationCurve = Curves.decelerate,
  }) : super(key: key);

  /// The widget below this widget in the tree.
  ///
  /// {@macro flutter.widgets.child}
  final Widget child;

  /// The duration of the animation to show when the system keyboard intrudes
  /// into the space that the dialog is placed in.
  ///
  /// Defaults to 100 milliseconds.
  final Duration insetAnimationDuration;

  /// The curve to use for the animation shown when the system keyboard intrudes
  /// into the space that the dialog is placed in.
  ///
  /// Defaults to [Curves.fastOutSlowIn].
  final Curve insetAnimationCurve;

  /// {@template flutter.material.dialog.shape}
  /// The shape of this dialog's border.
  ///
  /// Defines the dialog's [Material.shape].
  ///
  /// The default shape is a [RoundedRectangleBorder] with a radius of 2.0.
  /// {@endtemplate}

  @override
  Widget build(BuildContext context) {
    return AnimatedPadding(
      padding: MediaQuery.of(context).viewInsets +
          const EdgeInsets.symmetric(horizontal: 40.0, vertical: 24.0),
      duration: insetAnimationDuration,
      curve: insetAnimationCurve,
      child: MediaQuery.removeViewInsets(
        removeLeft: true,
        removeTop: true,
        removeRight: true,
        removeBottom: true,
        context: context,
        child: Center(
          child: ConstrainedBox(
            constraints: const BoxConstraints(),
            child: child,
          ),
        ),
      ),
    );
  }
}

//the code below is writeen by Vikas-Jilla and the above code is from existing material dialog library
class ModernFormProgressDialog {
  bool isDismissed = true;
  var lock = Lock();
  Timer _timer;
  BuildContext get context => ModernFormGlobalContext.context;

  Future<void> dismissProgressDialog({
    BuildContext customContext,
  }) async {
    _timer?.cancel();
    await lock.synchronized(() async {
      if (isDismissed == null || isDismissed) {
        return;
      }
      isDismissed = true;
      Navigator.of(customContext ?? context).pop();
    });
  }

  void showProgressDialog({
    Color barrierColor = const Color(0x55222222),
    String textToBeDisplayed,
    Duration dismissAfter = const Duration(minutes: 180),
    Function onDismiss,
    Stream<double> streamValue,
    Stream<String> streamText,
    Color progressColor,
    BuildContext customContext,
  }) {
    dismissProgressDialog().then((_) {
      isDismissed = false;
      showGeneralDialog(
        context: customContext ?? context,
        barrierColor: barrierColor,
        pageBuilder: (context, animation1, animation2) {
          return _ModernFormProgressDialog(
            child: Container(
                padding: const EdgeInsets.all(20),
                child:
                    Column(mainAxisSize: MainAxisSize.min, children: <Widget>[
                  streamValue != null
                      ? StreamBuilder<double>(
                          stream: streamValue,
                          initialData: 0,
                          builder: (context, snapshot) {
                            return ModernFormProgressIndicator(
                              value: snapshot?.data ?? 0,
                              color: progressColor,
                            );
                          })
                      : ModernFormProgressIndicator(color: progressColor),
                  streamText != null
                      ? Padding(
                          padding: EdgeInsets.only(top: 20),
                          child: StreamBuilder<Object>(
                              stream: streamText,
                              initialData: "",
                              builder: (context, snapshot) {
                                return Material(
                                  color: Colors.transparent,
                                  child: Text(
                                    snapshot?.data ?? "",
                                    style: TextStyle(
                                      color: Colors.white,
                                      fontSize: ScreenUtil().setSp(14),
                                    ),
                                    textAlign: TextAlign.center,
                                  ),
                                );
                              }))
                      : textToBeDisplayed == null
                          ? Padding(
                              padding: EdgeInsets.all(0),
                            )
                          : Padding(
                              padding: EdgeInsets.only(top: 20),
                              child: Material(
                                color: Colors.transparent,
                                child: Text(
                                  textToBeDisplayed,
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: ScreenUtil().setSp(14),
                                  ),
                                  textAlign: TextAlign.center,
                                ),
                              ))
                ])),
          );
        },
        barrierDismissible: false,
        transitionDuration: const Duration(milliseconds: 100),
      ).then((dismissed) {
        isDismissed = dismissed;
      });
      if (dismissAfter == null) return;
      _timer = Timer(dismissAfter, () {
        dismissProgressDialog();
        if (onDismiss != null) onDismiss();
      });
    });
  }
}
